import {
    world,
    system
} from "@minecraft/server"

//console.warn("Succesfully Loaded Script");

world.afterEvents.entityHurt.subscribe((event) => {
    const source = event.damageSource;
    const target = event.hurtEntity;
    const damage = event.damage / 5;

    for (const player of world.getPlayers()) {
        const item = player?.getComponent("equippable").getEquipment("Mainhand")

        if (item?.hasTag("magicraft:is_saber") === true && source.cause === "entityAttack" && source.damagingEntity == player) {
            player.addEffect("weakness", 12, { showParticles: false, amplifier: 2 })
            if (target.location.y <= player.location.y + 2 && player.isOnGround == true && player.isSprinting == false) {
                target.addTag("target")
                target.runCommand("damage @e[tag=!target,type=!player,r=1.75] " + damage.toFixed(0) + " contact entity @p")
                target.runCommand("particle magicraft:sweep1 ~ ~1 ~")
                target.removeTag("target")
            }
        }
        else if (item?.hasTag("minecraft:is_sword") == true && source.cause == "entityAttack" && source.damagingEntity == player) {
            player.addEffect("weakness", 15, { showParticles: false, amplifier: 2 })
        }
        else if (item?.hasTag("minecraft:is_axe") == true && source.cause == "entityAttack" && source.damagingEntity == player) {
            player.addEffect("weakness", 24, { showParticles: false, amplifier: 2 })
        }
        else if (item?.hasTag("magicraft:is_battleaxe") == true && source.cause == "entityAttack" && source.damagingEntity == player) {
            player.addEffect("weakness", 29, { showParticles: false, amplifier: 4 })
            player.addEffect("slowness", 29, { showParticles: false, amplifier: 0 })
        }
        else if (item?.hasTag("magicraft:is_greatsword") == true && source.cause == "entityAttack" && source.damagingEntity == player) {
            player.addEffect("weakness", 24, { showParticles: false, amplifier: 3 })
            player.addEffect("slowness", 24, { showParticles: false, amplifier: 0 })
        }
    }

    if (source.cause == "fall" && event.damage >= 5 && event.damage < 10) {
        target.addEffect("slowness", 100, { showParticles: false, amplifier: 1 })
    }
    else if (source.cause == "fall" && event.damage >= 10) {
        target.addEffect("slowness", 100, { showParticles: false, amplifier: 1 })
        target.addEffect("mining_fatigue", 100, { showParticles: false, amplifier: 1 })
    }
})

world.afterEvents.itemStopUse.subscribe((event) => {
    const chargeTime = event.useDuration;

    for (const player of world.getPlayers()) {
        const item = player?.getComponent("equippable").getEquipment("Mainhand")

        if ((item?.hasTag("magicraft:is_spellbook") || item?.hasTag("magicraft:is_scroll")) && chargeTime > 19960) {
            player.playSound("item.book.put")
        }
        if (item?.hasTag("magicraft:is_spell") && chargeTime > 19960) {
            player.playSound("beacon.deactivate")
        }
    }
})

world.afterEvents.itemReleaseUse.subscribe((event) => {
    const chargeTime = event.useDuration;

    for (const player of world.getPlayers()) {

        //Set minimum xp given to 1
        const spellXp = Math.max(1, (player.totalXpNeededForNextLevel * 0.0588));

        //Get mainhand item
        const item = player?.getComponent("equippable").getEquipment("Mainhand")

        //Spell casting sound
        if (item?.hasTag("magicraft:is_spell") == true && chargeTime <= 19960) {
            player.playSound("mob.evocation_illager.cast_spell")
        }

        //Spellbook sounds
        if ((item?.hasTag("magicraft:is_spellbook") || item?.hasTag("magicraft:is_scroll")) && chargeTime <= 19960) {
            player.playSound("block.enchanting_table.use")
        }

        //Grant XP when spell is cast
        if (item?.hasTag("magicraft:is_spell") == true && chargeTime <= 19960) {
            player.addExperience(spellXp)
        }


        //Healing Spells
        if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.addEffect("regeneration", 100, { showParticles: false, amplifier: 0 })
            player.startItemCooldown("magicraft:heal_spells", 200);
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.addEffect("regeneration", 100, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:heal_spells", 200);
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.addEffect("regeneration", 100, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:heal_spells", 200);
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.addEffect("regeneration", 100, { showParticles: false, amplifier: 2 })
            player.startItemCooldown("magicraft:heal_spells", 200);
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.addEffect("regeneration", 100, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:heal_spells", 200);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.addEffect("regeneration", 200, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:heal_spells", 400);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:heal_spell" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.addEffect("regeneration", 200, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:heal_spells", 400);
        }


        //Resistance Spells
        if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.addEffect("resistance", 1200, { showParticles: false, amplifier: 0 })
            player.startItemCooldown("magicraft:resistance_spells", 1800);
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.addEffect("resistance", 1200, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:resistance_spells", 1800);
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.addEffect("resistance", 3600, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:resistance_spells", 5400);
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.addEffect("resistance", 3600, { showParticles: false, amplifier: 2 })
            player.startItemCooldown("magicraft:resistance_spells", 5400);
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.addEffect("resistance", 6000, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 9000);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.addEffect("resistance", 7500, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 11250);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:resistance_spell" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.addEffect("resistance", 7500, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 11250);
        }


        //Fire Resistance Spells
        if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.addEffect("fire_resistance", 1200, { showParticles: false, amplifier: 0 })
            player.startItemCooldown("magicraft:resistance_spells", 1800);
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.addEffect("fire_resistance", 1200, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:resistance_spells", 1800);
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.addEffect("fire_resistance", 3600, { showParticles: false, amplifier: 1 })
            player.startItemCooldown("magicraft:resistance_spells", 5400);
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.addEffect("fire_resistance", 3600, { showParticles: false, amplifier: 2 })
            player.startItemCooldown("magicraft:resistance_spells", 5400);
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.addEffect("fire_resistance", 6000, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 9000);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.addEffect("fire_resistance", 7500, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 11250);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:fire_protection" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.addEffect("fire_resistance", 7500, { showParticles: false, amplifier: 3 })
            player.startItemCooldown("magicraft:resistance_spells", 11250);
        }


        //Fang Evocation Spells
        //Level 0-5
        if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.runCommand("execute at @e[family=monster,r=5] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        //Level 5
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.runCommand("execute at @e[family=monster,r=10] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        //Level 10
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.runCommand("execute at @e[family=monster,r=15] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        //Level 15
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.runCommand("execute at @e[family=monster,r=20] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        //Level 20
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.runCommand("execute at @e[family=monster,r=25] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 25
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.runCommand("execute at @e[family=monster,r=30] run summon evocation_fang ~ ~ ~")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 35
        else if (item?.typeId == "magicraft:fang_summoning" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.runCommand("execute at @e[family=monster,r=35] run summon evocation_fang ~ ~ ~")
        }

        //Induce Wither Spells
        //Level 0-5
        if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.runCommand("effect @e[family=monster,r=5] wither 10 0 true")
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        //Level 5
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.runCommand("effect @e[family=monster,r=10] wither 10 1 true")
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        //Level 10
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.runCommand("effect @e[family=monster,r=15] wither 10 1 true")
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        //Level 15
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.runCommand("effect @e[family=monster,r=20] wither 10 1 true")
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        //Level 20
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.runCommand("effect @e[family=monster,r=25] wither 10 1 true")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 25
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.runCommand("effect @e[family=monster,r=30] wither 10 2 true")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 35
        else if (item?.typeId == "magicraft:induce_wither" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.runCommand("effect @e[family=monster,r=35] wither 10 3  true")
        }


        //Night Sight Spells
        if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.addEffect("night_vision", 1200, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 1800);
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.addEffect("night_vision", 2400, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 1800);
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.addEffect("night_vision", 3600, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 5400);
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.addEffect("night_vision", 4800, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 5400);
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.addEffect("night_vision", 6000, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 9000);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.addEffect("night_vision", 7200, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 11250);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        else if (item?.typeId == "magicraft:night_vision_spell" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.addEffect("night_vision", 8400, { showParticles: false })
            player.startItemCooldown("magicraft:support_spells", 11250);
        }


        //Reanimation Spells
        //Level 0-5
        if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.runCommand("function reanimate")
            player.startItemCooldown("magicraft:attack_spells", 1200);
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        //Level 5
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.runCommand("function reanimate")
            player.startItemCooldown("magicraft:attack_spells", 1200);
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        //Level 10
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.runCommand("function reanimate")
            player.startItemCooldown("magicraft:attack_spells", 1200);
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        //Level 15
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.runCommand("function reanimate2")
            player.startItemCooldown("magicraft:attack_spells", 1200);
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        //Level 20
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.runCommand("function reanimate2")
            player.startItemCooldown("magicraft:attack_spells", 1200)
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 25
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.runCommand("function reanimate2")
            player.startItemCooldown("magicraft:attack_spells", 1200);
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 35
        else if (item?.typeId == "magicraft:reanimation_spell" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.runCommand("function reanimate2")
        }



        //Summon Thunder Spells
        //Level 0-5
        if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.runCommand("execute at @e[family=monster,r=5] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        //Level 5
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.runCommand("execute at @e[family=monster,r=10] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        //Level 10
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.runCommand("execute at @e[family=monster,r=15] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        //Level 15
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.runCommand("execute at @e[family=monster,r=20] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        //Level 20
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.runCommand("execute at @e[family=monster,r=25] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 25
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.runCommand("execute at @e[family=monster,r=30] run summon lightning_bolt ~ ~ ~")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 35
        else if (item?.typeId == "magicraft:thunder_spell" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.runCommand("execute at @e[family=monster,r=35] run summon lightning_bolt ~ ~ ~")
        }

        //Summon Familiar spells
        //Level 0-5
        if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() <= 55) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 100, { showParticles: false, amplifier: 50 })
            player.addEffect("darkness", 200, { showParticles: false, amplifier: 0 })
        }
        //Level 5
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 55 && player.getTotalXp() <= 160) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 80, { showParticles: false, amplifier: 50 })
        }
        //Level 10
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 160 && player.getTotalXp() <= 315) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 60, { showParticles: false, amplifier: 75 })
        }
        //Level 15
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 315 && player.getTotalXp() <= 550) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 40, { showParticles: false, amplifier: 100 })
        }
        //Level 20
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 550 && player.getTotalXp() <= 910) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 150 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 25
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 910 && player.getTotalXp() <= 2045) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
            player.addEffect("hunger", 20, { showParticles: false, amplifier: 200 })
            player.addEffect("slowness", 60, { showParticles: false, amplifier: 0 })
        }
        //Level 35
        else if (item?.typeId == "magicraft:summon_familiar" && chargeTime <= 19960 && player.getTotalXp() >= 2045) {
            player.startItemCooldown("magicraft:support_spells", 4800);
            player.runCommand("summon magicraft:familiar ~ ~ ~ facing @p")
        }


        //Use Spellbooks
        if (item?.typeId == "magicraft:tome_healing" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:heal_spell")
        }

        if (item?.typeId == "magicraft:tome_resistance" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:resistance_spell")
        }

        if (item?.typeId == "magicraft:tome_fireprot" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:fire_protection")
        }

        if (item?.typeId == "magicraft:tome_fang" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:fang_summoning")
        }

        if (item?.typeId == "magicraft:tome_familiar" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:summon_familiar")
        }

        if (item?.typeId == "magicraft:tome_nv" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:night_vision_spell")
        }

        if (item?.typeId == "magicraft:tome_reanimate" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:reanimation_spell")
        }

        if (item?.typeId == "magicraft:tome_wither" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:induce_wither")
        }

        if (item?.typeId == "magicraft:tome_thunder" && chargeTime <= 19960) {
            player.runCommand("replaceitem entity @s slot.weapon.mainhand 0 magicraft:thunder_spell")
        }

        //Use scrolls
        if (item?.typeId == "magicraft:scroll_healing" && chargeTime <= 19960) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container

            player.addEffect("instant_health", 1, { showParticles: false, amplifier: 0 })

            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
        else if (item?.typeId == "magicraft:scroll_resistance" && chargeTime <= 19960) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container

            player.addEffect("resistance", 1200, { showParticles: false, amplifier: 0 })

            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
        else if (item?.typeId == "magicraft:scroll_nv" && chargeTime <= 19960) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container

            player.addEffect("night_vision", 1200, { showParticles: false, amplifier: 0 })

            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
    }
})

world.afterEvents.itemStartUse.subscribe((event) => {
    for (const player of world.getPlayers()) {
        const item = player?.getComponent("equippable").getEquipment("Mainhand")

        //Start casting spell
        if (item?.hasTag("magicraft:is_spell") == true) {
            player.playSound("mob.evocation_illager.prepare_summon")
        }

        //Spellbook start sound
        if (item?.hasTag("magicraft:is_spellbook") || item?.hasTag("magicraft:is_scroll")) {
            player.playSound("item.book.page_turn")
        }
    }
})

world.afterEvents.playerBreakBlock.subscribe((event) => {
    for (const player of world.getPlayers()) {
        const item = player?.getComponent("equippable").getEquipment("Mainhand")

        if (item?.hasTag("minecraft:is_pickaxe") || item?.hasTag("minecraft:is_sword") || item?.hasTag("minecraft:is_shovel") || item?.hasTag("minecraft:is_axe") || item?.hasTag("minecraft:is_hoe") || item?.hasTag("magicraft:is_battleaxe") || item?.hasTag("magicraft:is_saber") || item?.hasTag("magicraft:is_greatsword")) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container
            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
    }
})

world.afterEvents.itemUseOn.subscribe((event) => {
    const block = event.block;

    for (const player of world.getPlayers()) {
        const item = player?.getComponent("equippable").getEquipment("Mainhand")


        if (item?.hasTag("minecraft:is_axe") && block.hasTag("wood")) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container
            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
        else if (item?.hasTag("minecraft:is_shovel") && block.hasTag("grass")) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container
            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
        else if (item?.hasTag("minecraft:is_hoe") && block.hasTag("dirt")) {
            const damage = item.getComponent("durability").damage;
            const durability = item.getComponent("durability").maxDurability;
            const inv = player.getComponent("inventory").container
            if (damage == durability) {
                inv.setItem(player.selectedSlotIndex, null)
            }
            else {
                item.getComponent("durability").damage += 1;
                inv.setItem(player.selectedSlotIndex, item);
            }
        }
    }
})